<?php
/**
 * Slicko Header Settings panel at Theme Customizer
 *
 * @package Slicko
 * @since 1.0.0
 */

add_action( 'customize_register', 'slicko_header_settings_register' );

function slicko_header_settings_register( $wp_customize ) {

	/**
     * Add General Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel('slicko_header_settings_panel',array(
        'priority'       => 10,
        'capability'     => 'edit_theme_options',
        'theme_supports' => '',
        'title'          => esc_html__( 'Header Settings', 'slicko' ),
    ));


    $wp_customize->get_section('header_image')->panel = 'slicko_header_settings_panel';
    $wp_customize->get_section('header_image')->title = esc_html__('Header Background Image', 'slicko');
    $wp_customize->get_section('header_image')->priority = 3;

     /**
     * Website layout section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'slicko_header_background_section',
        array(
            'title'         => esc_html__( 'Header Background Color', 'slicko' ),
            'description'   => esc_html__( 'Choose Header Background Color.', 'slicko' ),
            'priority'      => 55,
            'panel'         => 'slicko_header_settings_panel',
        )
    );

    $wp_customize->add_setting(
        'header_background_color',
        array(
            'default' => '#ececec',
            'transport' => 'postMessage',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    );
    
    $wp_customize->add_control( 
        new WP_Customize_Color_Control( 
        $wp_customize, 
        'header_background_color', 
        array(
            'label'      => esc_html__( 'Header Background Color', 'slicko' ),
            'section'    => 'slicko_header_background_section',
            'priority'   => 20,
        ) ) 
    );

    $wp_customize->add_section(
        'slicko_header_content_section',
        array(
            'title'         => esc_html__( 'Blog Header Content', 'slicko' ),
            'priority'      => 55,
            'panel'         => 'slicko_header_settings_panel',
        )
    );
    // Heading
    $wp_customize->add_setting(
        'slicko_header_heading_text',
        array(
            'default'    => esc_html__( 'The Slick Blog by Danny James', 'slicko' ),
            'transport'  => 'postMessage',
            'sanitize_callback' => 'slicko_minimal_html_senitize'
        )
    );
    $wp_customize->add_control(
        'slicko_header_heading_text',
        array(
            'type'      => 'textarea',
            'label'     => esc_html__( 'Blog Heading', 'slicko' ),
            'section'   => 'slicko_header_content_section',
            'priority'  => 5,
        )
    );
    $wp_customize->selective_refresh->add_partial(
        'slicko_header_heading_text',
        array(
            'selector' => 'h1.post__title.blog-heading',
            'render_callback' => 'slicko_customize_partial_blog_heading',
        )
    );

    // Heading
    $wp_customize->add_setting(
        'slicko_header_dis_text',
        array(
            'default'    => esc_html__( 'Read latest news from our blog & learn new things.', 'slicko' ),
            'transport'  => 'postMessage',
            'sanitize_callback' => 'slicko_minimal_html_senitize'
        )
    );
    $wp_customize->add_control(
        'slicko_header_dis_text',
        array(
            'type'      => 'textarea',
            'label'     => esc_html__( 'Blog Caption', 'slicko' ),
            'section'   => 'slicko_header_content_section',
            'priority'  => 5,
        )
    );
    $wp_customize->selective_refresh->add_partial(
        'slicko_header_dis_text',
        array(
            'selector' => '.front-page',
            'render_callback' => 'slicko_customize_partial_dis_heading',
        )
    );


    $wp_customize->add_setting(
        'slicko_bread_menu',
        array(
            'default' => 'show',
            'sanitize_callback' => 'slicko_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new slicko_Customize_Switch_Control(
        $wp_customize,
            'slicko_bread_menu',
            array(
                'type'      => 'switch',
                'label'     => esc_html__( 'Show Breadcrumb', 'slicko' ),
                'description'   => esc_html__( 'Show/Hide option for Blog post page.', 'slicko' ),
                'section'   => 'slicko_header_content_section',
                'choices'   => array(
                    'show'  => esc_html__( 'Show', 'slicko' ),
                    'hide'  => esc_html__( 'Hide', 'slicko' )
                ),
                'priority'  => 10,
            )
        )
    );




} // header panel close